<?php

# PHP config
error_reporting(E_ALL);

$names = array(
  'rf01'=>'hc0403',
  'rf02'=>'hc0404',
  'rf03'=>'hc0405',
  'rf05'=>'hc0406',
  'rf06'=>'hc0407',
  'rf07'=>'hc0408',
  'rf08'=>'hc0409',
  'rf09'=>'hc0410',
  'rf11'=>'hc0501',
  'rf12'=>'hc0502',
  'rf13'=>'hc0503',
  'rf14'=>'hc0504',
  'rf15'=>'hc0505',
);

# purging temporary files
exec("rm ../tmp/*");

# argument parsing
$code = $argv[1];
$tasfile = "../../data/$code/Tasfile_1";
$fsspfile = "";
$animname = 'anim_'.$code.'.gif';

# get info about time of beg/end of data in dbfiles
$date = strtotime(`fgrep FlightDate $tasfile | cut -d '=' -f 2`.' UTC');
$title = "RICO ".gmdate('Y-m-d', $date)." NCAR C-130 flight $code";
if (isset($names[$code])) $title .= " / ".$names[$code];

# column definitions for tasfile
$col_lat = 9;
$col_lon = 10;
$col_alt = 3;
$col_lwc = 8;
$col_time = "($date+\\\$1)";

# min and max values
$min = `head -100 $tasfile | grep -v '^#' 2>/dev/null | head -1 | awk '{print $1}'`;
$max = `tail -100 $tasfile | grep -v '^#' 2>/dev/null | tail -1 | awk '{print $1}'`;

$i = $min;
while ($i%900!=0) $i-=1;

# prepare array of times for animation

if ($i%900==0 && $i%1800!=0) {
  $frames[] = array(
    'msgdate' => gmdate('Ymd', $date+$i),
    'msghour' => gmdate('Hi', $date+$i),
    'ind' => '0',
    'sec' => $i
  );
  $i+=900;
  $idx = 1;
} else {
  $idx = 0;
}

for (; $i<$max; $i+=900) {
  if ($i%1800==0) {
    $frames[] = array(
      'msgdate' => gmdate('Ymd', $date+$i+900),
      'msghour' => gmdate('Hi', $date+$i+900),
      'ind' => $idx.':'.($idx+1),
      'sec' => $i
    );
    $idx+=2;
  }
}

foreach ($frames as $i => $framedata) {
  $id = sprintf("%02d", $i);

  print("Preparing animation frame for {$framedata['msgdate']} {$framedata['msghour']}Z\n");

  # preparing transparent plots for every frame
  $gpl = "
    fl2m(x) = x
 
    set term png transparent enhanced 14 size 1150,351
    set output '../tmp/frame_{$id}_fg.png'
    set grid
    set timefmt \\\"%s\\\"

    set multiplot 

    set origin 0,0
    set size ratio -1 .6,1
    set xrange [-65:-55]
    set yrange [15:20]
    set xtics 1
    set ytics 1
    set xlabel 'longitude'
    set ylabel 'latitude'
    set nokey
    set label 'GOES-12 CH1 VIS  {$framedata['msgdate']} {$framedata['msghour']}Z' at -59, 15.2 textcolor lt 1
    plot '$tasfile+' using $col_lon:$col_lat t '' with lines lw 1, '$tasfile+' index {$framedata['ind']} using $col_lon:$col_lat t '' with lines lw 4 lt 3

    unset label
    set xdata time
    set format x \\\"%R\\\"
    set title '$title'
    set origin .58,0
    set size noratio .42,1
    set xlabel ''
    set ylabel 'GPS altitude [m]'
    set y2label 'liquid water content [g/m3]'
    set y2tics
    set ytics 500
    set xtics 1000 rotate
    set key below
    set autoscale
    set y2range [0:1]
    set yrange [0:5000]
    plot '$tasfile+' using $col_time:$col_lwc axes x1y2 t 'LWC (Gerber PV-100)' with impulses lw 1 lt 2, \\
         '$tasfile+' index {$framedata['ind']} using $col_time:$col_lwc axes x1y2 t '' with impulses lw 4 lt 4, \\
         '$tasfile+' using $col_time:(fl2m(".'\$'."$col_alt)) axes x1y1 t 'GPS altitude' with lines lw 1 lt 1, \\
         '$tasfile+' index {$framedata['ind']} using $col_time:(fl2m(".'\$'."$col_alt)) axes x1y1 t '' with lines lw 4 lt 3

    set nomultiplot
  ";
  $cmd = "echo \"$gpl\" | gnuplot";
  `$cmd`;

  # preparing detailed LWC/h plot
  $gpl = "
    set term png transparent enhanced 14 size 1150,145
    set output '../tmp/frame_{$id}_details.png'
    set grid

    set xlabel 'time UT [hh:mm]'
    set ylabel 'GPS altitude [m]'
    set y2label 'LWC [g/m3]'
    set y2tics
    set autoscale
    set y2range [0:1]
    set yrange [0:5000]
    set nokey
    set timefmt \\\"%s\\\"
    set xdata time
    set format x \\\"%R\\\"

    plot '$tasfile+' index {$framedata['ind']} using $col_time:$col_lwc axes x1y2 t 'LWC (Gerber PV-100)' with impulses lw 1 lt 2, \\
         '$tasfile+' index {$framedata['ind']} using $col_time:$col_alt axes x1y1 t 'GPS altitude' with lines lw 1 lt 1

  ";
  $cmd = "echo \"$gpl\" | gnuplot";
  `$cmd`;


  # preparing backgrounds for every frame
  $file = "../../goes-12/ops.goes-12.{$framedata['msgdate']}{$framedata['msghour']}.4km_ch1_vis.jpg";
  if (!file_exists($file)) $file = "../img/missing.png"; 
  `convert $file -crop 279x147+32+333 ../tmp/frame_{$id}_bg.png`;

  #expanding the bg
  `convert ../tmp/frame_{$id}_bg.png -support 0.5 -resize 600x300! ../tmp/frame_{$id}_bg.png`;
  `convert ../tmp/frame_{$id}_bg.png -bordercolor white -border 80x15 ../tmp/frame_{$id}_bg.png`;
  `convert ../tmp/frame_{$id}_bg.png -gravity southeast -background white -splice 427x27 ../tmp/frame_{$id}_bg.png`;

  #composing frames
  $cmd = "composite -gravity center -compose Atop ../tmp/frame_{$id}_fg.png ../tmp/frame_{$id}_bg.png ../tmp/frame_{$id}.png";
  `$cmd`;

  #adding BT scale
  `composite -gravity southwest -compose Atop ../img/btscale_vis.png ../tmp/frame_{$id}.png ../tmp/frame_{$id}.png` ;

  #preparing movie strip
  $files = '';
  if (substr($framedata['msghour'],2,2) == '15') $minutes = array('00','05','10','15','20','25');
  else $minutes = array('30','35','40','45','50','55');
  foreach ($minutes as $min) {
    $file = "c130_fwd_".substr($framedata['msgdate'],2,6)."_".substr($framedata['msghour'],0,2).$min.'00';
    $file_in = "../../data/$code/jpg_0.1Hz/".$file.".jpg";
    if (!file_exists("../../data/$code/jpg_0.1Hz/$file.jpg")) {
      printf("Camera file missing! ($file.jpg)\n");
      $file_in = "../img/missing.png";
    }
    #resizeing image
    $file_out = substr($framedata['msghour'],0,2).'.'.$min;
    `convert $file_in -support 0.5 -resize 185x185 png:../tmp/$file_out`;
    $files .= " png:../tmp/$file_out";
  }
  `montage -label %f -geometry +4+4 -tile 6x1 $files ../tmp/movie_strip_{$id}.png`;

  #adding movie strip 
  `montage -geometry +1+1 -gravity north -tile 1x2 ../tmp/frame_{$id}.png ../tmp/movie_strip_{$id}.png ../tmp/frame_{$id}.png`;

  # cropping
  `convert ../tmp/frame_{$id}.png -crop 1189x505+0+0 ../tmp/frame_{$id}.png`;

  #adding detailed plot
  `montage -geometry +1+1 -gravity north -tile 1x2 ../tmp/frame_{$id}.png ../tmp/frame_{$id}_details.png ../tmp/frame_{$id}.png`;

  # cropping
  `convert ../tmp/frame_{$id}.png -crop 1189x655+0+0 ../tmp/frame_{$id}.png`;

  #adding UW stamp
  `composite -gravity southeast -compose Atop ../img/uwg.png ../tmp/frame_{$id}.png ../tmp/frame_{$id}.png`;

}
# cleaning temp files
`rm ../tmp/frame_*_fg.png`;
`rm ../tmp/frame_*_bg.png`;
`rm ../tmp/frame_*_details.png`;

# making the animation
printf("Composing animation file...");
`convert -delay 300 -size 1100x500 -loop 0 -page +0+0 ../tmp/frame_*.png ../$animname`;
`rm ../tmp/*.png`;
printf(" OK\n");

?>
